@@ -342,12 +342,12 @@ const inputSourceContainerTemplate = `{{- define "inputSourceContainerTemplate"
   @type tail
   @id container-input
   path "/var/log/containers/*.log"
+  exclude_path ["/var/log/containers/{{.CollectorPodNamePrefix}}-*_{{.LoggingNamespace}}_*.log", "/var/log/containers/{{.LogStorePodNamePrefix}}-*_{{.LoggingNamespace}}_*.log", "/var/log/containers/{{.VisualizationPodNamePrefix}}-*_{{.LoggingNamespace}}_*.log"]
   pos_file "/var/log/es-containers.log.pos"
   refresh_interval 5
   rotate_wait 5
   tag kubernetes.*
   read_from_head "true"
-  exclude_path []
   @label @CONCAT
   <parse>
     @type multi_format
@@ -508,7 +508,7 @@ const forwardTemplate = `{{- define "forward" }}
 	<buffer>
 		@type file
 		path '{{.BufferPath}}'
-		queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
+		queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 		chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m' }"
 		flush_interval "#{ENV['FORWARD_FLUSH_INTERVAL'] || '5s'}"
 		flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
@@ -570,7 +570,7 @@ const storeElasticsearchTemplate = `{{- define "storeElasticsearch" }}
 		flush_at_shutdown "#{ENV['FLUSH_AT_SHUTDOWN'] || 'false'}"
 		retry_max_interval "#{ENV['ES_RETRY_WAIT'] || '300'}"
 		retry_forever true
-		queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
+		queue_limit_length "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 		chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m' }"
 		overflow_action "#{ENV['BUFFER_QUEUE_FULL_ACTION'] || 'block'}"
 	</buffer>
