@@ -1,19 +1,24 @@
 package k8shandler
 
 import (
+	"fmt"
 	"reflect"
 	"testing"
 
+	configv1 "github.com/openshift/api/config/v1"
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
+	logforward "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1alpha1"
+	"github.com/openshift/cluster-logging-operator/pkg/constants"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 func TestNewFluentdPodSpecWhenFieldsAreUndefined(t *testing.T) {
 
 	cluster := &logging.ClusterLogging{}
-	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name")
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, logforward.ForwardingSpec{})
 
 	if len(podSpec.Containers) != 1 {
 		t.Error("Exp. there to be 1 fluentd container")
@@ -39,7 +44,7 @@ func TestNewFluentdPodSpecWhenResourcesAreDefined(t *testing.T) {
 	requestCPU := resource.MustParse("500m")
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			Collection: logging.CollectionSpec{
+			Collection: &logging.CollectionSpec{
 				logging.LogCollectionSpec{
 					Type: "fluentd",
 					FluentdSpec: logging.FluentdSpec{
@@ -49,7 +54,7 @@ func TestNewFluentdPodSpecWhenResourcesAreDefined(t *testing.T) {
 			},
 		},
 	}
-	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name")
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, logforward.ForwardingSpec{})
 
 	if len(podSpec.Containers) != 1 {
 		t.Error("Exp. there to be 1 fluentd container")
@@ -84,14 +89,14 @@ func TestFluentdPodSpecHasTaintTolerations(t *testing.T) {
 
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			Collection: logging.CollectionSpec{
+			Collection: &logging.CollectionSpec{
 				logging.LogCollectionSpec{
 					Type: "fluentd",
 				},
 			},
 		},
 	}
-	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name")
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, logforward.ForwardingSpec{})
 
 	if !reflect.DeepEqual(podSpec.Tolerations, expectedTolerations) {
 		t.Errorf("Exp. the tolerations to be %v but was %v", expectedTolerations, podSpec.Tolerations)
@@ -104,7 +109,7 @@ func TestNewFluentdPodSpecWhenSelectorIsDefined(t *testing.T) {
 	}
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			Collection: logging.CollectionSpec{
+			Collection: &logging.CollectionSpec{
 				logging.LogCollectionSpec{
 					Type: "fluentd",
 					FluentdSpec: logging.FluentdSpec{
@@ -114,7 +119,7 @@ func TestNewFluentdPodSpecWhenSelectorIsDefined(t *testing.T) {
 			},
 		},
 	}
-	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name")
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, logforward.ForwardingSpec{})
 
 	if !reflect.DeepEqual(podSpec.NodeSelector, expSelector) {
 		t.Errorf("Exp. the nodeSelector to be %q but was %q", expSelector, podSpec.NodeSelector)
@@ -137,7 +142,7 @@ func TestNewFluentdPodNoTolerations(t *testing.T) {
 
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			Collection: logging.CollectionSpec{
+			Collection: &logging.CollectionSpec{
 				logging.LogCollectionSpec{
 					Type:        "fluentd",
 					FluentdSpec: logging.FluentdSpec{},
@@ -146,7 +151,7 @@ func TestNewFluentdPodNoTolerations(t *testing.T) {
 		},
 	}
 
-	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name")
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, logforward.ForwardingSpec{})
 	tolerations := podSpec.Tolerations
 
 	if !utils.AreTolerationsSame(tolerations, expTolerations) {
@@ -178,7 +183,7 @@ func TestNewFluentdPodWithTolerations(t *testing.T) {
 
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
-			Collection: logging.CollectionSpec{
+			Collection: &logging.CollectionSpec{
 				logging.LogCollectionSpec{
 					Type: "fluentd",
 					FluentdSpec: logging.FluentdSpec{
@@ -191,10 +196,104 @@ func TestNewFluentdPodWithTolerations(t *testing.T) {
 		},
 	}
 
-	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name")
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, logforward.ForwardingSpec{})
 	tolerations := podSpec.Tolerations
 
 	if !utils.AreTolerationsSame(tolerations, expTolerations) {
 		t.Errorf("Exp. the tolerations to be %v but was %v", expTolerations, tolerations)
 	}
 }
+
+func TestNewFluentdPodSpecWhenProxyConfigExists(t *testing.T) {
+
+	cluster := &logging.ClusterLogging{}
+	httpproxy := "http://proxy-user@test.example.com/3128/"
+	noproxy := ".cluster.local,localhost"
+	caBundle := fmt.Sprint("-----BEGIN CERTIFICATE-----\n<PEM_ENCODED_CERT>\n-----END CERTIFICATE-----\n")
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name",
+		&configv1.Proxy{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "Proxy",
+				APIVersion: "config.openshift.io/v1",
+			},
+			Spec: configv1.ProxySpec{
+				HTTPProxy:  httpproxy,
+				HTTPSProxy: httpproxy,
+				TrustedCA: configv1.ConfigMapNameReference{
+					Name: "user-ca-bundle",
+				},
+			},
+			Status: configv1.ProxyStatus{
+				HTTPProxy:  httpproxy,
+				HTTPSProxy: httpproxy,
+				NoProxy:    noproxy,
+			},
+		},
+		&v1.ConfigMap{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "openshift-logging",
+				Name:      constants.FluentdTrustedCAName,
+			},
+			Data: map[string]string{
+				constants.TrustedCABundleKey: caBundle,
+			},
+		},
+		logforward.ForwardingSpec{},
+	)
+
+	if len(podSpec.Containers) != 1 {
+		t.Error("Exp. there to be 1 fluentd container")
+	}
+
+	checkFluentdProxyEnvVar(t, podSpec, "HTTP_PROXY", httpproxy)
+	checkFluentdProxyEnvVar(t, podSpec, "HTTPS_PROXY", httpproxy)
+	checkFluentdProxyEnvVar(t, podSpec, "NO_PROXY", noproxy)
+
+	checkFluentdProxyVolumesAndVolumeMounts(t, podSpec, constants.FluentdTrustedCAName)
+}
+
+func checkFluentdProxyEnvVar(t *testing.T, podSpec v1.PodSpec, name string, value string) {
+	env := podSpec.Containers[0].Env
+	found := false
+	for _, elem := range env {
+		if elem.Name == name {
+			found = true
+			if elem.Value != value {
+				t.Errorf("EnvVar %s: expected %s, actual %s", name, value, elem.Value)
+			}
+		}
+	}
+	if !found {
+		t.Errorf("EnvVar %s not found", name)
+	}
+}
+
+func checkFluentdProxyVolumesAndVolumeMounts(t *testing.T, podSpec v1.PodSpec, trustedca string) {
+	volumemounts := podSpec.Containers[0].VolumeMounts
+	found := false
+	for _, elem := range volumemounts {
+		if elem.Name == trustedca {
+			found = true
+			if elem.MountPath != constants.TrustedCABundleMountDir {
+				t.Errorf("VolumeMounts %s: expected %s, actual %s", trustedca, constants.TrustedCABundleMountDir, elem.MountPath)
+			}
+		}
+	}
+	if !found {
+		t.Errorf("VolumeMounts %s not found", trustedca)
+	}
+
+	volumes := podSpec.Volumes
+	found = false
+	for _, elem := range volumes {
+		if elem.Name == trustedca {
+			found = true
+			if elem.VolumeSource.ConfigMap.LocalObjectReference.Name != trustedca {
+				t.Errorf("Volume %s: expected %s, actual %s", trustedca, trustedca, elem.VolumeSource.Secret.SecretName)
+			}
+		}
+	}
+	if !found {
+		t.Errorf("Volume %s not found", trustedca)
+	}
+}
